## Synopsis

ecco_v4_py is a Python package that includes tools for loading and manipulating the ECCO v4 ocean and sea-ice state estimate (http://ecco-group.org)


## Installation

### Using pip

pip install ecco_v4_py


## API Reference

Documention can be found here: http://ecco-v4-python-tutorial.readthedocs.io/index.html#

## Contributors

If you would like to contribute, please contact ecco-support@mit.edu or Ian.Fenty at jpl.nasa.gov

## License

MIT License
